==> react-native-common-ui-0.1.2.tgz: package/js/Basics/Background.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useEffect, useState } from 'react';
import { StyleSheet, View } from 'react-native';
import { isSvg } from 'react-native-svg-component';
import { ImageUtils } from '../Utils/Image';
import { Image } from './Image';
export const Background = (props) => {
    const [state, setState] = useState({
        resize: 'cover',
        containerRatio: 1,
    });
    const { children, source, fill, onLayout } = props, others = __rest(props, ["children", "source", "fill", "onLayout"]);
    const onContainerSize = (event) => {
        if (onLayout) {
            onLayout(event);
        }
        if (event.nativeEvent.layout.width > 0 && event.nativeEvent.layout.height > 0) {
            setState(Object.assign({}, state, { containerRatio: event.nativeEvent.layout.width / event.nativeEvent.layout.height }));
        }
    };
    const onSizeFetched = (width, height) => {
        if (width > 0 && height > 0) {
            const ratio = width / height;
            if (fill === 'horizontal') {
                if (ratio > state.containerRatio) {
                    setState(Object.assign({}, state, { resize: 'cover' }));
                }
                else {
                    setState(Object.assign({}, state, { resize: 'contain' }));
                }
            }
            else if (fill === 'vertical') {
                if (ratio < state.containerRatio) {
                    setState(Object.assign({}, state, { resize: 'cover' }));
                }
                else {
                    setState(Object.assign({}, state, { resize: 'contain' }));
                }
            }
            else if (fill === 'auto') {
                setState(Object.assign({}, state, { resize: 'center' }));
            }
            else {
                setState(Object.assign({}, state, { resize: fill }));
            }
        }
    };
    const onSizeError = (error) => {
        console.log(`Fetch size failed. Error:${error}`);
    };
    useEffect(() => {
        const uri = props.source.uri;
        if (!isSvg(uri) || fill === 'horizontal' || fill === 'vertical' || fill === 'auto') {
            ImageUtils.fetchSize(uri, onSizeFetched, onSizeError);
        }
        else {
            setState(Object.assign({}, state, { resize: fill }));
        }
    }, [props.source, props.fill]);
    return (React.createElement(View, Object.assign({}, others, { onLayout: onContainerSize }),
        React.createElement(Image, { source: source, alt: 'background', style: StyleSheet.absoluteFill, resizeMode: state.resize }),
        children));
};

==> react-native-common-ui-0.2.0.tgz: package/js/Basics/Background.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useEffect, useState } from 'react';
import { StyleSheet, View } from 'react-native';
import { isSvg } from 'react-native-svg-component';
import { ImageUtils } from '../Utils/Image';
import { Image } from './Image';
export const Background = (props) => {
    const [state, setState] = useState({
        resize: 'cover',
        containerRatio: 1,
    });
    const { children, source, fill, onLayout } = props, others = __rest(props, ["children", "source", "fill", "onLayout"]);
    const onContainerSize = (event) => {
        if (onLayout) {
            onLayout(event);
        }
        if (event.nativeEvent.layout.width > 0 && event.nativeEvent.layout.height > 0) {
            setState(Object.assign(Object.assign({}, state), { containerRatio: event.nativeEvent.layout.width / event.nativeEvent.layout.height }));
        }
    };
    const onSizeFetched = (width, height) => {
        if (width > 0 && height > 0) {
            const ratio = width / height;
            if (fill === 'horizontal') {
                if (ratio > state.containerRatio) {
                    setState(Object.assign(Object.assign({}, state), { resize: 'cover' }));
                }
                else {
                    setState(Object.assign(Object.assign({}, state), { resize: 'contain' }));
                }
            }
            else if (fill === 'vertical') {
                if (ratio < state.containerRatio) {
                    setState(Object.assign(Object.assign({}, state), { resize: 'cover' }));
                }
                else {
                    setState(Object.assign(Object.assign({}, state), { resize: 'contain' }));
                }
            }
            else if (fill === 'auto') {
                setState(Object.assign(Object.assign({}, state), { resize: 'center' }));
            }
            else {
                setState(Object.assign(Object.assign({}, state), { resize: fill }));
            }
        }
    };
    const onSizeError = (error) => {
        console.log(`Fetch size failed. Error:${error}`);
    };
    useEffect(() => {
        const uri = props.source.uri;
        if (!isSvg(uri) || fill === 'horizontal' || fill === 'vertical' || fill === 'auto') {
            ImageUtils.fetchSize(uri, onSizeFetched, onSizeError);
        }
        else {
            setState(Object.assign(Object.assign({}, state), { resize: fill }));
        }
    }, [props.source, props.fill]);
    return (React.createElement(View, Object.assign({}, others, { onLayout: onContainerSize }),
        React.createElement(Image, { source: source, alt: 'background', style: StyleSheet.absoluteFill, resizeMode: state.resize }),
        children));
};
